/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

namespace Diorite.Logger{
	private const string LOG_DOMAIN = "Diorite";
	public static string domain;
	public static GLib.LogLevelFlags level;
	public static long time = 0;
	
	public static void init(string domain, GLib.LogLevelFlags level=GLib.LogLevelFlags.LEVEL_DEBUG){
		Diorite.Logger.domain = domain;
		Diorite.Logger.level = level;
		GLib.Log.set_default_handler(Logger.log_handler);
	}
	
	public static void log_handler(string? domain, LogLevelFlags level, string message){
		if(level > Diorite.Logger.level) return;
		if(time != 0){
			var current_time = TimeVal();
			current_time.get_current_time();
			stdout.printf("%5.5s ", (current_time.tv_sec - time).to_string());
		}
		stdout.printf("%10.10s ", domain ?? "<unknown>");
		
		string name = "";
		switch (level) {
			case LogLevelFlags.FLAG_RECURSION:
				name = "Recursion";
				break;
			case LogLevelFlags.FLAG_FATAL:
				name = "Fatal";
				break;
			case LogLevelFlags.LEVEL_CRITICAL:
				name = "Critical";
				break;
			case LogLevelFlags.LEVEL_ERROR:
				name = "Error";
				break;
			case LogLevelFlags.LEVEL_WARNING:
				name = "Warning";
				break;
			case LogLevelFlags.LEVEL_MESSAGE:
			case LogLevelFlags.LEVEL_INFO:
				name = "Info";
				break;
			case LogLevelFlags.LEVEL_DEBUG:
				name = "Debug";
				break;
			case LogLevelFlags.LEVEL_MASK:
				name = "Mask";
				break;
			default:
				name = "Unknown";
				break;
		}
		stdout.printf ("%8.8s ", name);
		stdout.printf(message);
		stdout.printf("\n");
		
	}
	
	/**
	 * Logs  message with domain specified in Logger.domain.
	 * 
	 * @param level Level of message
	 * @param format format string
	 */
	public static void log_with_level(GLib.LogLevelFlags level, string format, ...){
		va_list args = va_list();
		GLib.logv(Diorite.Logger.domain, level, format, args);
	}
	
	
	/**
	 * Logs debug message with libfenryxo domain
	 * @param format format string
	 */
	private static void lib_debug(string format, ...){
		va_list args = va_list();
		GLib.logv(LOG_DOMAIN, LogLevelFlags.LEVEL_DEBUG, format, args);
	}
	
	/**
	 * Logs info message with libfenryxo domain
	 * @param format format string
	 */
	private static void lib_message(string format, ...){
		va_list args = va_list();
		GLib.logv(LOG_DOMAIN, LogLevelFlags.LEVEL_MESSAGE, format, args);
	}
	
	/**
	 * Logs warning with libfenryxo domain
	 * @param format format string
	 */
	private static void lib_warning(string format, ...){
		va_list args = va_list();
		GLib.logv(LOG_DOMAIN, LogLevelFlags.LEVEL_WARNING, format, args);
	}
	
	/**
	 * Logs critical warning with libfenryxo domain
	 * @param format format string
	 */
	private static void lib_critical(string format, ...){
		va_list args = va_list();
		GLib.logv(LOG_DOMAIN, LogLevelFlags.LEVEL_CRITICAL, format, args);
	}
	
	/**
	 * Logs error message with libfenryxo domain
	 * @param format format string
	 */
	private static void lib_error(string format, ...){
		va_list args = va_list();
		GLib.logv(LOG_DOMAIN, LogLevelFlags.LEVEL_ERROR, format, args);
	}
}
