/*
 * Copyright 2013 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

using Diorite.Logger;

/**
 * Module providing developer's bar
 */
namespace Nuvola.Extensions.DeveloperBar{

/**
 * Returns plugin information
 * 
 * @return plugin information
 */
public Nuvola.ExtensionInfo get_info(){
	return {
		/// Name of a plugin providing developer's bar
		_("Developer's bar"),
		Config.VERSION,
		/// Description of a plugin providing developer's bar
		_("<p>This plugin shows developers's bar with information about current playback status.</p>"),
		"Jiří Janoušek",
		typeof(Extension),
		false
	};
}

/**
 * Developer's bar
 */
public class Extension: Nuvola.Extension{
	private weak Nuvola.Player player;
	private Diorite.InfoBar? bar = null;
	private weak MainWindow? main_window;
	
	/**
	 * {@inheritDoc}
	 */
	public override void load(ObjectContainer objects) throws Nuvola.ExtensionError{
		// Get dependencies, throws ExtensionError
		player = objects.get<Player>("player");
		main_window = objects.get<MainWindow>("main_window");
		bar = new Diorite.InfoBar.info("Loading...");
		main_window.box.pack_end(bar, false);
		bar.show();
		
		player.song_changed.connect(on_song_changed);
		player.notify["playback-state"].connect(on_playback_state_changed);
		update();
	}
	
	/**
	 * {@inheritDoc}
	 */
	public override void unload(){
		player.song_changed.disconnect(on_song_changed);
		player.notify["playback-state"].disconnect(on_playback_state_changed);
		main_window.box.remove(bar);
		bar = null;
	}
	
	private void on_song_changed(string? song, string? artist, string? album, string? album_art)
	{
		update();
	}
	
	private void on_playback_state_changed(GLib.Object o, ParamSpec p)
	{
		update();
	}
	
	private void update()
	{
		return_if_fail(bar != null);
		bar.label.label = "State: %s. Song info: %s by %s from %s".printf(player.playback_state,
		Markup.escape_text(player.song ?? "[null song]"),
		Markup.escape_text(player.artist ?? "[null artist]"),
		Markup.escape_text(player.album ?? "[null album]"));
	}
}


} // namespace Nuvola.Extensions.DeveloperBar
