/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

using Diorite.Logger;

public class Nuvola.AboutDialog: Gtk.AboutDialog{
	public static string get_welcome_message(){
		/// Welcome infomation for new releases (shown only once). %1$s - $4%s will be links
		return _("<b>Tip:</b> You can follow Nuvola Player on <a href='%1$s'>Google+</a>, <a href='%2$s'>Facebook</a> or <a href='%3$s'>Twitter</a> to get fresh news and service update packages."
		).printf(Config.GOOGLE_PLUS_URL, Config.FACEBOOK_URL, Config.TWITTER_URL);
	}
	
	public AboutDialog(Diorite.Application app){
		try {
			this.icon = Gtk.IconTheme.get_default().load_icon(app.icon, 48, 0);
		}
		catch(Error e){
			warning("Unable to load application icon.");
		}
		set_size_request(300, -1);
		this.copyright = Config.COPYRIGHT;
		this.website = Config.WEBSITE;
		this.version = app.version;
		this.program_name = app.display_name;
		this.logo_icon_name = app.icon;
		/// Shown in the About Nuvola Player dialog
		this.comments = _("Cloud music integration for your Linux desktop.");
		/// Names of translators (shown in the translator credits accessed from the About Nuvola Player dialog)
		this.translator_credits = _("translator-credits");
		this.artists = {
			"Alexander King <https://plus.google.com/117767008472331887156/about>",
			"Arturo Torres Sánchez <arturo.ilhuitemoc@gmail.com>"};
		this.authors = {
			"Jiří Janoušek <janousek.jiri@gmail.com>",
			"Janez Troha <janez.troha@gmail.com>",
			"Adam Wolfe Gordon <awg@xvx.ca>",
			"Stefan Lohmaier <stefan.lohmaier@googlemail.com>",
			"Michael Mims <mims.michael@gmail.com>",
			"Ionică Bizău <bizauionica@gmail.com>"
		};
		
		var box = get_content_area() as Gtk.Box;
		var label = new Diorite.WrappedLabel(get_welcome_message(), true);
		label.xalign = 0.5f;
		box.pack_start(label, false, false, 10);
		label.show();
		
		
	}
	
	public override bool delete_event(Gdk.EventAny event){
		return false;
	}
}
