/*
 * Copyright 2011-2012 Jiří Janoušek <janousek.jiri@gmail.com>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

using Diorite.Widgets;

namespace Nuvola
{

public class NoServiceOverlay: Gtk.EventBox
{
	
	public NoServiceOverlay(Diorite.Actions actions){
		Object();
		
		var top = 0;
		var left = 0;
		const int COLUMNS = 2;
		const int MARGIN = 15;
		
		var grid = new Gtk.Grid();
		grid.column_homogeneous = true;
		grid.column_spacing = grid.row_spacing = MARGIN;
		grid.halign = Gtk.Align.CENTER;
		grid.valign = Gtk.Align.CENTER;
		add(grid);
		grid.show();
		
		var label = new Gtk.Label("");
		label.set_markup(Markup.printf_escaped("<big><big><big><b>%s</b></big></big></big>",
			_("No streaming service is loaded.")));
		grid.attach(label, left, top++, COLUMNS, 1);
		label.margin = MARGIN;
		label.show();
		
		var big_text = new Pango.AttrList();
		big_text.change(Pango.attr_scale_new(Pango.Scale.X_LARGE));
		
		
//~ 		string[] action_names = {"switch-service", "website", "questions", "extensions-settings", "preferences", "quit"};
		string[] action_names = {"switch-service", "website", "preferences", "quit"};
		foreach(var action_name in action_names)
		{
			var action = actions.get_action(action_name);
			if (action != null)
			{
				var button = new Diorite.ActionImageButton(action, Gtk.IconSize.DIALOG);
				if (action_name == "switch-service")
					button.label_widget.set_text(_("Load service"));
				button.label_widget.set_attributes(big_text);
				button.get_child().margin = MARGIN;
				if (left >= COLUMNS)
				{
					left = 0;
					top++;
				}
				grid.attach(button, left++, top, 1, 1);
				button.show();
			}
			else
				critical("Unable to find action %s", action_name);
		}
		
	}
	
	#if DEBUG_MEMORY
	~NoServiceOverlay()
	{
		debug("~WelcomeGrid()");
	}
	#endif
}

} // namespace Nuvola
